@@ -1,7 +1,7 @@
 package Getopt::Panjang;
 
 our $DATE = '2015-09-15'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -82,7 +82,7 @@ sub get_options {
     } else {
         $argv = \@ARGV;
     }
-    my $spec = $args{spec};
+    my $spec = $args{spec} or return [400, "Please specify spec"];
     ref($args{spec}) eq 'HASH' or return [400, "spec is not a hash"];
     for (keys %$spec) {
         return [400, "spec->{$_} is not a coderef"]
@@ -294,7 +294,7 @@ Getopt::Panjang - Parse command-line options
 
 =head1 VERSION
 
-This document describes version 0.02 of Getopt::Panjang (from Perl distribution Getopt-Panjang), released on 2015-09-15.
+This document describes version 0.03 of Getopt::Panjang (from Perl distribution Getopt-Panjang), released on 2015-09-15.
 
 =head1 SYNOPSIS
 
@@ -305,10 +305,11 @@ This document describes version 0.02 of Getopt::Panjang (from Perl distribution
      # similar to Getopt::Long, except values must be coderef (handler), and
      # handler receives hash argument
      spec => {
-         'foo'   => sub { $opts->{foo} = 1 },
-         'bar=s' => sub { my %a = @_; $opts->{bar} = $a{value} },
+         'bar'   => sub { $opts->{bar} = 1 },
+         'baz=s' => sub { my %a = @_; $opts->{baz} = $a{value} },
+         'err=s' => sub { die "Bzzt\n" },
      },
-     argv => ["--bar", 1, "--foo"], # defaults to @ARGV
+     argv => ["--baz", 1, "--bar"], # defaults to @ARGV
  );
 
  if ($res->[0] == 200) {
@@ -333,6 +334,60 @@ This document describes version 0.02 of Getopt::Panjang (from Perl distribution
     }
  }
 
+Sample success result when C<@ARGV> is C<< ["--baz", 1, "--bar"] >>:
+
+ [200, "OK", undef, { "func.remaining_argv" => [] }]
+
+Sample error result (ambiguous option) when C<@ARGV> is C<< ["--ba", 1] >>:
+
+ [
+   500,
+   "Error in parsing",
+   undef,
+   {
+     "func.ambiguous_opts" => { ba => ["bar", "baz"] },
+     "func.remaining_argv" => [1],
+   },
+ ]
+
+Sample error result (option with missing value) when C<@ARGV> is C<< ["--bar",
+"--baz"] >>:
+
+[
+   500,
+   "Error in parsing",
+   undef,
+   {
+     "func.remaining_argv"   => [],
+     "func.val_missing_opts" => { baz => 1 },
+   },
+ ]
+
+Sample error result (unknown option) when C<@ARGV> is C<< ["--foo", "--qux"] >>:
+
+ [
+    500,
+   "Error in parsing",
+   undef,
+   {
+     "func.remaining_argv" => ["--foo", "--qux"],
+     "func.unknown_opts"   => { foo => 1, qux => 1 },
+   },
+ ]
+
+Sample error result (option with invalid value where the option handler dies)
+when C<@ARGV> is C<< ["--err", 1] >>:
+
+ [
+   500,
+   "Error in parsing",
+   undef,
+   {
+     "func.remaining_argv"   => [],
+     "func.val_invalid_opts" => { err => "Invalid value for option 'err': Bzzt\n" },
+   },
+ ]
+
 =head1 DESCRIPTION
 
 B<EXPERIMENTAL WORK>.
@@ -407,27 +462,27 @@ Remaining argv after parsing is returned in the result metadata.
 
 Sample startup overhead benchmark:
 
-                            Rate      run_gl     load_gl load_gl_less       run_gp      load_gp  run_gl_less load_gl_evenless run_gl_evenless   perl
- run_gl              60.2+-1.1/s          --       -8.5%       -71.8%       -72.8%       -73.0%       -75.8%           -77.8%          -82.8% -90.9%
- load_gl             65.8+-1.6/s   9.3+-3.3%          --       -69.2%       -70.3%       -70.5%       -73.6%           -75.8%          -81.2% -90.1%
- load_gl_less       213.4+-2.2/s 254.6+-7.4% 224.4+-8.5%           --        -3.6%        -4.4%       -14.3%           -21.4%          -39.1% -67.8%
- run_gp            221.4+-0.78/s 267.8+-6.7% 236.5+-8.2%    3.7+-1.1%           --        -0.8%       -11.0%           -18.5%          -36.8% -66.6%
- load_gp          223.14+-0.71/s 270.7+-6.8% 239.2+-8.2%    4.6+-1.1%  0.79+-0.48%           --       -10.3%           -17.8%          -36.3% -66.3%
- run_gl_less      248.87+-0.59/s 313.5+-7.5% 278.3+-9.1%   16.6+-1.3% 12.41+-0.48% 11.53+-0.45%           --            -8.4%          -29.0% -62.5%
- load_gl_evenless   271.6+-6.7/s    351+-14%    313+-14%   27.3+-3.4%   22.7+-3.1%     21.7+-3%    9.1+-2.7%               --          -22.5% -59.0%
- run_gl_evenless    350.4+-1.1/s    482+-11%    433+-13%   64.2+-1.8% 58.28+-0.75%  57.05+-0.7% 40.81+-0.56%         29+-3.2%              -- -47.1%
- perl                 663+-1.5/s   1002+-20%    908+-24%  210.7+-3.3%  199.5+-1.2%  197.1+-1.2% 166.4+-0.87%      144.1+-6.1%    89.19+-0.73%     --
+                            Rate      run_gl     load_gl      load_gp       run_gp run_gl_less load_gl_less run_gl_evenless load_gl_evenless   perl
+ run_gl             71.95+-0.3/s          --       -3.8%       -67.2%       -68.0%      -68.1%       -71.7%          -75.3%           -81.2% -89.2%
+ load_gl           74.81+-0.33/s 3.97+-0.62%          --       -65.9%       -66.7%      -66.8%       -70.6%          -74.3%           -80.4% -88.8%
+ load_gp            219.6+-0.4/s 205.2+-1.4% 193.5+-1.4%           --        -2.2%       -2.5%       -13.7%          -24.5%           -42.5% -67.0%
+ run_gp           224.54+-0.34/s 212.1+-1.4% 200.1+-1.4%  2.25+-0.24%           --       -0.4%       -11.8%          -22.8%           -41.2% -66.2%
+ run_gl_less        225.3+-2.4/s 213.2+-3.6% 201.2+-3.5%    2.6+-1.1%    0.4+-1.1%          --       -11.5%          -22.5%           -41.0% -66.1%
+ load_gl_less         254.5+-1/s   253.7+-2%   240.2+-2% 15.89+-0.51% 13.34+-0.49%  12.9+-1.3%           --          -12.5%           -33.4% -61.7%
+ run_gl_evenless    290.7+-1.2/s 304.1+-2.3% 288.6+-2.3%  32.4+-0.59% 29.49+-0.56%    29+-1.5% 14.25+-0.66%              --           -23.9% -56.3%
+ load_gl_evenless     382+-1.2/s 430.9+-2.7% 410.6+-2.7% 73.94+-0.62% 70.12+-0.58%  69.5+-1.9%  50.1+-0.76%    31.38+-0.67%               -- -42.6%
+ perl                 665.2+-3/s 824.5+-5.6% 789.2+-5.6%  202.9+-1.5%  196.3+-1.4% 195.2+-3.4%  161.4+-1.6%     128.8+-1.4%     74.16+-0.94%     --
  
  Average times:
-   perl            :     1.5083ms
-   run_gl_evenless :     2.8539ms
-   load_gl_evenless:     3.6819ms
-   run_gl_less     :     4.0182ms
-   load_gp         :     4.4815ms
-   run_gp          :     4.5167ms
-   load_gl_less    :     4.6860ms
-   load_gl         :    15.1976ms
-   run_gl          :    16.6113ms
+   perl            :     1.5033ms
+   load_gl_evenless:     2.6178ms
+   run_gl_evenless :     3.4400ms
+   load_gl_less    :     3.9293ms
+   run_gl_less     :     4.4385ms
+   run_gp          :     4.4535ms
+   load_gp         :     4.5537ms
+   load_gl         :    13.3672ms
+   run_gl          :    13.8985ms
 
 =head1 FUNCTIONS
 
